@@ -13,6 +13,9 @@ from typing import TYPE_CHECKING, Annotated
 import typer
 from rich.console import Console
 
+from chzzk.cli.tui import can_run_tui, run_tui
+from chzzk.cli.tui.apps import ChatViewerApp, InteractiveChatApp
+from chzzk.constants import StatusText
 from chzzk.exceptions import ChatConnectionError, ChatNotLiveError
 from chzzk.unofficial import (
     AsyncUnofficialChzzkClient,
@@ -53,14 +56,16 @@ def format_chat_message(msg: ChatMessage, json_output: bool = False) -> str:
                 "user_id_hash": msg.user_id_hash,
                 "nickname": msg.nickname,
                 "content": msg.content,
-                "badge": msg.profile.badge.name if msg.profile and msg.profile.badge else None,
+                "badge": (
+                    msg.profile.badge.get("name") if msg.profile and msg.profile.badge else None
+                ),
             }
         )
 
     timestamp = datetime.now().strftime("%H:%M:%S")
     badge = ""
     if msg.profile and msg.profile.badge:
-        badge = f"[{msg.profile.badge.name}] " if msg.profile.badge.name else ""
+        badge = f"[{msg.profile.badge.get('name')}] " if msg.profile.badge.get("name") else ""
 
     return f"[dim]{timestamp}[/dim] {badge}[cyan]{msg.nickname}[/cyan]: {msg.content}"
 
@@ -100,14 +105,63 @@ def watch(
             help="Connect to chat even when channel is offline",
         ),
     ] = False,
+    no_tui: Annotated[
+        bool,
+        typer.Option(
+            "--no-tui",
+            help="Disable TUI and use simple console output",
+        ),
+    ] = False,
 ) -> None:
     """Watch real-time chat messages from a channel.
 
     By default, only connects when the channel is live.
     Use --offline to connect to chat even when offline.
+
+    By default, displays a full-screen TUI with scrollable messages.
+    Use --no-tui for simple console output.
     """
     nid_aut, nid_ses = get_auth_cookies(ctx)
     json_output = ctx.obj.get("json_output", False)
+    config = get_config(ctx)
+
+    # Use TUI if available and not disabled/json mode
+    if not json_output and not no_tui and can_run_tui():
+        viewer_app = ChatViewerApp(
+            config=config,
+            channel_id=channel_id,
+            nid_aut=nid_aut,
+            nid_ses=nid_ses,
+            allow_offline=offline,
+        )
+        run_tui(viewer_app)
+
+        if viewer_app.error_message:
+            console.print(f"[red]Error:[/red] {viewer_app.error_message}")
+            raise typer.Exit(1)
+        return
+
+    # Fallback to console output
+    if not no_tui and not json_output:
+        logger.info("TUI mode unavailable, using console mode")
+    _run_watch_console(
+        channel_id=channel_id,
+        nid_aut=nid_aut,
+        nid_ses=nid_ses,
+        offline=offline,
+        json_output=json_output,
+    )
+
+
+def _run_watch_console(
+    *,
+    channel_id: str,
+    nid_aut: str | None,
+    nid_ses: str | None,
+    offline: bool,
+    json_output: bool,
+) -> None:
+    """Run chat watch with console output (fallback mode)."""
 
     async def run_chat() -> None:
         async with AsyncUnofficialChzzkClient(nid_aut=nid_aut, nid_ses=nid_ses) as client:
@@ -135,7 +189,7 @@ def watch(
             # Connect to chat
             try:
                 if not json_output:
-                    status_text = "LIVE" if live_detail.is_live else "OFFLINE"
+                    status_text = StatusText.LIVE if live_detail.is_live else StatusText.OFFLINE
                     console.print(
                         f"[green]Connecting to chat...[/green] "
                         f"({live_detail.channel_name or channel_id} - {status_text})"
@@ -240,6 +294,13 @@ def send(
             help="Interactive chat mode (send and receive messages)",
         ),
     ] = False,
+    no_tui: Annotated[
+        bool,
+        typer.Option(
+            "--no-tui",
+            help="Disable TUI and use simple console input/output",
+        ),
+    ] = False,
 ) -> None:
     """Send a chat message to a channel.
 
@@ -248,9 +309,13 @@ def send(
     By default, sends a single message and exits. Use --interactive for
     a persistent connection where you can send and receive messages.
     Use --offline to connect even when the channel is offline.
+
+    In interactive mode, displays a full-screen TUI by default.
+    Use --no-tui for simple console input/output.
     """
     nid_aut, nid_ses = get_auth_cookies(ctx)
     json_output = ctx.obj.get("json_output", False)
+    config = get_config(ctx)
 
     if not nid_aut or not nid_ses:
         if json_output:
@@ -274,7 +339,27 @@ def send(
         raise typer.Exit(1)
 
     if interactive:
-        _run_interactive_chat(
+        # Use TUI if available and not disabled/json mode
+        if not json_output and not no_tui and can_run_tui():
+            interactive_app = InteractiveChatApp(
+                config=config,
+                channel_id=channel_id,
+                nid_aut=nid_aut,
+                nid_ses=nid_ses,
+                allow_offline=offline,
+            )
+            run_tui(interactive_app)
+
+            if interactive_app.error_message:
+                console.print(f"[red]Error:[/red] {interactive_app.error_message}")
+                raise typer.Exit(1)
+            return
+
+        # Fallback to console interactive mode
+        if not no_tui and not json_output:
+            logger.info("TUI mode unavailable, using console mode")
+        _run_interactive_chat_console(
+            config=config,
             channel_id=channel_id,
             nid_aut=nid_aut,
             nid_ses=nid_ses,
@@ -282,9 +367,11 @@ def send(
             json_output=json_output,
         )
     else:
+        # message is guaranteed to be non-None here (checked above)
+        assert message is not None
         _send_single_message(
             channel_id=channel_id,
-            message=message,  # type: ignore[arg-type]
+            message=message,
             nid_aut=nid_aut,
             nid_ses=nid_ses,
             offline=offline,
@@ -349,15 +436,57 @@ def _send_single_message(
         raise typer.Exit(1) from None
 
 
-def _run_interactive_chat(
+def _run_interactive_chat_console(
     *,
+    config: ConfigManager,
     channel_id: str,
     nid_aut: str,
     nid_ses: str,
     offline: bool,
     json_output: bool,
 ) -> None:
-    """Run interactive chat mode."""
+    """Run interactive chat with console input/output (fallback mode).
+
+    For non-JSON mode, uses Textual inline mode for proper cancellation.
+    For JSON mode, uses async stdin reading with timeout on cancellation.
+    """
+    if not json_output:
+        # Use inline Textual app for non-JSON mode - this allows proper cancellation
+        interactive_app = InteractiveChatApp(
+            config=config,
+            channel_id=channel_id,
+            nid_aut=nid_aut,
+            nid_ses=nid_ses,
+            allow_offline=offline,
+            inline_mode=True,
+        )
+        run_tui(interactive_app, inline=True, inline_height=15)
+
+        if interactive_app.error_message:
+            console.print(f"[red]Error:[/red] {interactive_app.error_message}")
+            raise typer.Exit(1)
+        return
+
+    # JSON mode uses async stdin reading
+    _run_interactive_chat_json(
+        channel_id=channel_id,
+        nid_aut=nid_aut,
+        nid_ses=nid_ses,
+        offline=offline,
+    )
+
+
+def _run_interactive_chat_json(
+    *,
+    channel_id: str,
+    nid_aut: str,
+    nid_ses: str,
+    offline: bool,
+) -> None:
+    """Run interactive chat with JSON output (no TUI).
+
+    Uses asyncio.to_thread(input) with timeout on cancellation.
+    """
 
     async def run_chat() -> None:
         async with AsyncUnofficialChzzkClient(nid_aut=nid_aut, nid_ses=nid_ses) as client:
@@ -365,67 +494,37 @@ def _run_interactive_chat(
 
             @chat.on_chat
             async def handle_chat(msg: ChatMessage) -> None:
-                console.print(format_chat_message(msg, json_output))
+                console.print(format_chat_message(msg, json_output=True))
 
             @chat.on_donation
             async def handle_donation(msg: DonationMessage) -> None:
-                console.print(format_donation_message(msg, json_output))
+                console.print(format_donation_message(msg, json_output=True))
 
-            # Get live detail first to check status
+            # Get live detail first to check status (validates channel exists)
             try:
-                live_detail = await client.live.get_live_detail(channel_id)
+                await client.live.get_live_detail(channel_id)
             except Exception as e:
                 logger.error(f"Failed to get live detail: {e}")
-                if json_output:
-                    console.print(json.dumps({"error": str(e)}))
-                else:
-                    console.print(f"[red]Error:[/red] {e}")
+                console.print(json.dumps({"error": str(e)}))
                 raise typer.Exit(1) from None
 
             # Connect to chat
             try:
-                if not json_output:
-                    status_text = "LIVE" if live_detail.is_live else "OFFLINE"
-                    console.print(
-                        f"[green]Connecting to chat...[/green] "
-                        f"({live_detail.channel_name or channel_id} - {status_text})"
-                    )
-
                 await chat.connect(channel_id, allow_offline=offline)
-
-                if not json_output:
-                    console.print(
-                        f"[green]Connected![/green] Interactive chat for "
-                        f"[cyan]{live_detail.channel_name or channel_id}[/cyan]"
-                    )
-                    console.print(
-                        "[dim]Type messages and press Enter to send. Ctrl+C to exit.[/dim]\n"
-                    )
-
             except ChatNotLiveError:
-                if json_output:
-                    console.print(
-                        json.dumps(
-                            {
-                                "error": "Channel is not live",
-                                "channel_id": channel_id,
-                                "hint": "Use --offline to connect anyway",
-                            }
-                        )
-                    )
-                else:
-                    console.print(
-                        f"[yellow]Channel {channel_id} is not live.[/yellow]\n"
-                        f"Use [cyan]--offline[/cyan] to connect to chat anyway."
+                console.print(
+                    json.dumps(
+                        {
+                            "error": "Channel is not live",
+                            "channel_id": channel_id,
+                            "hint": "Use --offline to connect anyway",
+                        }
                     )
+                )
                 raise typer.Exit(1) from None
-
             except ChatConnectionError as e:
                 logger.error(f"Failed to connect to chat: {e}")
-                if json_output:
-                    console.print(json.dumps({"error": str(e)}))
-                else:
-                    console.print(f"[red]Connection error:[/red] {e}")
+                console.print(json.dumps({"error": str(e)}))
                 raise typer.Exit(1) from None
 
             # Handle graceful shutdown
@@ -446,7 +545,7 @@ def _run_interactive_chat(
                         line = await asyncio.to_thread(input)
                         if line and not stop_event.is_set():
                             await chat.send_message(line)
-                            console.print(format_sent_message(line, json_output))
+                            console.print(format_sent_message(line, json_output=True))
                     except EOFError:
                         # stdin closed
                         break
@@ -462,10 +561,9 @@ def _run_interactive_chat(
                 pass
             finally:
                 input_task.cancel()
-                with contextlib.suppress(asyncio.CancelledError):
-                    await input_task
-                if not json_output:
-                    console.print("\n[yellow]Disconnected[/yellow]")
+                # Use timeout to avoid blocking on the uncancellable input() thread
+                with contextlib.suppress(asyncio.CancelledError, TimeoutError):
+                    await asyncio.wait_for(input_task, timeout=0.1)
 
     with contextlib.suppress(KeyboardInterrupt):
         asyncio.run(run_chat())
